// @ts-nocheck
import '../styles/globals.css';
import 'bootstrap/dist/css/bootstrap.css';

import type { AppProps } from 'next/app';
import Head from 'next/head';
import { SecuredComponent } from '../components/types/auth';
import LoggedUserProvider from '../contexts/LoggedUserContext';
import Auth from '../components/common/Auth';

function MyApp({
    Component,
    pageProps,
}: {
    Component: SecuredComponent;
    pageProps: AppProps['pageProps'];
}) {
    return (
        <LoggedUserProvider>
            <Head>
                <link rel="shortcut icon" href={'/favicon.ico'} />
                <title>Annotation Tool</title>
            </Head>
            {Component.auth ? (
                <Auth minRole={Component.auth?.minRole}>
                    <Component {...pageProps} />
                </Auth>
            ) : (
                <Component {...pageProps} />
            )}
        </LoggedUserProvider>
    );
}

export default MyApp;
